// partition:  a container for organizing a set of sequential integers
//             into non-overlapping groups.
// Version:    0.1
// Copyright 2013 Matthew T. Busche.
//
// This program is free software:  you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the Free
// Software Foundation, either version 3 of the License, or (at your option)
// any later version.
//
// This program is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
// more details.
//
// You should have received a copy of the GNU General Public License along
// with this program.  If not, see <http://www.gnu.org/licenses/>.

package org.mattbusche.util.partition;

/** <p>An instance of Entry&lt;M&gt; is a simple data pair consisting  of an integer
 ** ID and a user-provided member object of type M.  An Entry's member may
 ** be null.</p>
 **
 ** @author Matthew T. Busche
 ** @version 0.1
 **/
public class Entry<M>
{
    final int id;
    M member;

    /** Constructs an Entry with the given ID and a null member.
     **/
    Entry(int id)
    {
        this.id = id;
    }

    /** Constructs an Entry with the given ID and member.
     **/
    Entry(int id, M member)
    {
        this.id = id;
        this.member = member;
    }

    /** Returns the Entry ID.
     **/
    public int getId()
    {
        return id;
    }

    /** Returns the Entry member.
     **/
    public M getMember()
    {
        return member;
    }

    /** Sets the Entry member.
     **/
    public void setMember(M member)
    {
        this.member = member;
    }


    /** <p>Prints the Entry in the following format:</p>
     ** <pre>
     **       (id, member)
     ** </pre>
     **/
    @Override
    public String toString()
    {
        return "(" + id + ", " + member + ")";
    }
}
